==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortHttp2ErrorBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HTTPFaultInjectionAbortHttp2ErrorBuilder extends HTTPFaultInjectionAbortHttp2ErrorFluentImpl<HTTPFaultInjectionAbortHttp2ErrorBuilder> implements VisitableBuilder<HTTPFaultInjectionAbortHttp2Error,HTTPFaultInjectionAbortHttp2ErrorBuilder>{
  public HTTPFaultInjectionAbortHttp2ErrorBuilder() {
    this(false);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(Boolean validationEnabled) {
    this(new HTTPFaultInjectionAbortHttp2Error(), validationEnabled);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HTTPFaultInjectionAbortHttp2Error(), validationEnabled);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent,HTTPFaultInjectionAbortHttp2Error instance) {
    this(fluent, instance, false);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent,HTTPFaultInjectionAbortHttp2Error instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHttp2Error(instance.getHttp2Error());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2Error instance) {
    this(instance,false);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2Error instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHttp2Error(instance.getHttp2Error());
    }
    this.validationEnabled = validationEnabled; 
  }
  HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent;
  Boolean validationEnabled;
  public HTTPFaultInjectionAbortHttp2Error build() {
    HTTPFaultInjectionAbortHttp2Error buildable = new HTTPFaultInjectionAbortHttp2Error(fluent.getHttp2Error());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortHttp2ErrorBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HTTPFaultInjectionAbortHttp2ErrorBuilder extends HTTPFaultInjectionAbortHttp2ErrorFluent<HTTPFaultInjectionAbortHttp2ErrorBuilder> implements VisitableBuilder<HTTPFaultInjectionAbortHttp2Error,HTTPFaultInjectionAbortHttp2ErrorBuilder>{
  public HTTPFaultInjectionAbortHttp2ErrorBuilder() {
    this(false);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(Boolean validationEnabled) {
    this(new HTTPFaultInjectionAbortHttp2Error(), validationEnabled);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HTTPFaultInjectionAbortHttp2Error(), validationEnabled);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent,HTTPFaultInjectionAbortHttp2Error instance) {
    this(fluent, instance, false);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent,HTTPFaultInjectionAbortHttp2Error instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HTTPFaultInjectionAbortHttp2Error());

    if (instance != null) {
      fluent.withHttp2Error(instance.getHttp2Error());
      fluent.withHttp2Error(instance.getHttp2Error());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2Error instance) {
    this(instance,false);
  }
  public HTTPFaultInjectionAbortHttp2ErrorBuilder(HTTPFaultInjectionAbortHttp2Error instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HTTPFaultInjectionAbortHttp2Error());

    if (instance != null) {
      this.withHttp2Error(instance.getHttp2Error());
      this.withHttp2Error(instance.getHttp2Error());
    }
    this.validationEnabled = validationEnabled; 
  }
  HTTPFaultInjectionAbortHttp2ErrorFluent<?> fluent;
  Boolean validationEnabled;
  public HTTPFaultInjectionAbortHttp2Error build() {
    HTTPFaultInjectionAbortHttp2Error buildable = new HTTPFaultInjectionAbortHttp2Error(fluent.getHttp2Error());
    return buildable;
  }
  
}
